
local StoneGateV5 = ...

-- Apply building asset processor
StoneGateV5:registerAssetProcessor("models/decorations/decoration.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Create default minor decoration part registering function 
function registerDefaultMinorDecorationPart(_nameFbx, _nameAsset, _stoneCost)
    StoneGateV5:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", "STONE_GATE_V5_DECORATION_" .. _nameAsset .. "_PREFAB")

    StoneGateV5:register({
	DataType = "BUILDING_PART",
	Id = "STONE_GATE_V5_DECORATION_" .. _nameAsset .. "_PART",
	Name = "STONE_GATE_V5_DECORATION_" .. _nameAsset .. "_NAME",
	Description = "STONE_GATE_V5_DECORATION_" .. _nameAsset .. "_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "STONE_GATE_V5_DECORATION_" .. _nameAsset .. "_PREFAB",
                IsPreviewGroundVisible = false
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _stoneCost }
		}
	}
    })

    StoneGateV5:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR", -- Snaps the decoration only on minor attach nodes (here only on the facades)
	BuildingZone = { 4, 4 }
    })
end

registerDefaultMinorDecorationPart("SFenetre", "SFENETRE", 1)
registerDefaultMinorDecorationPart("LFenetre", "LFENETRE", 1)
registerDefaultMinorDecorationPart("PFenetre", "PFENETRE", 1)
registerDefaultMinorDecorationPart("ArrowSlit", "ARROWSLIT", 1)
registerDefaultMinorDecorationPart("Lucarne", "LUCARNE", 1)
registerDefaultMinorDecorationPart("Balcony", "BALCONY", 2)
registerDefaultMinorDecorationPart("Chimney", "CHIMNEY", 1)
registerDefaultMinorDecorationPart("ChimneyBase", "CHIMNEY_BASE", 0)
registerDefaultMinorDecorationPart("DecorationDoorA", "DOOR_A", 1)
registerDefaultMinorDecorationPart("DecorationDoorB", "DOOR_B", 1)
registerDefaultMinorDecorationPart("DecorationDoorMA", "DOOR_MA", 1)
registerDefaultMinorDecorationPart("DecorationDoorMB", "DOOR_MB", 1)
registerDefaultMinorDecorationPart("Tourelle", "TURRET", 2)

-- Create default major decoration part registering function 
function registerDefaultMajorDecorationPart(_nameFbx, _nameAsset, _stoneCost)
    StoneGateV5:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", "STONE_GATE_V5_DECORATION_" .. _nameAsset .. "_PREFAB")

    StoneGateV5:register({
	DataType = "BUILDING_PART",
	Id = "STONE_GATE_V5_DECORATION_" .. _nameAsset .. "_PART",
	Name = "STONE_GATE_V5_DECORATION_" .. _nameAsset .. "_NAME",
	Description = "STONE_GATE_V5_DECORATION_" .. _nameAsset .. "_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "STONE_GATE_V5_DECORATION_" .. _nameAsset .. "_PREFAB",
                IsPreviewGroundVisible = false
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _stoneCost }
		}
	}
    })
end

registerDefaultMajorDecorationPart("Buttress", "BUTTRESS", 2)

-- Create default door decoration part registering function 
function registerDefaultDoorDecorationPart(_nameFbx, _nameAsset, _stoneCost)
    StoneGateV5:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Entrance/" .. _nameFbx .. "Part", "STONE_GATE_V5_ENTRANCE_" .. _nameAsset .. "_PREFAB")

    StoneGateV5:register({
	DataType = "BUILDING_PART",
	Id = "STONE_GATE_V5_ENTRANCE_" .. _nameAsset .. "_PART",
	Name = "STONE_GATE_V5_ENTRANCE_" .. _nameAsset .. "_NAME",
	Description = "STONE_GATE_V5_ENTRANCE_" .. _nameAsset .. "_DESC",
	Category = "DOOR",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "STONE_GATE_V5_ENTRANCE_" .. _nameAsset .. "_PREFAB",
                IsPreviewGroundVisible = false
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _stoneCost }
		}
	}
    })

-- Register grounding components
    StoneGateV5:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Entrance/" .. _nameFbx .. "Part", {
	DataType = "COMP_GROUNDED"
    })

--    StoneGateV5:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Entrance/" .. _nameFbx .. "Part", {
--	DataType = "COMP_BUILDING_PART",
--	BuildingPartType = "DOOR", -- Allows the door to be used as entrance
--	HasBuildingZone = true,
--	BuildingZone = { 1, 1 }
--    })
end

registerDefaultDoorDecorationPart("DoorA", "DOOR_A", 1)
registerDefaultDoorDecorationPart("DoorB", "DOOR_B", 1)

-- Register air vent particle system (flags)
    StoneGateV5:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart/SmokeEmitter", "STONE_GATE_V5_CHIMNEY_SMOKE_EMITTER_PREFAB")

    StoneGateV5:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart", {
	DataType = "COMP_BUILDING_PART",
	FeedbackComponentListToActivate = {
                 { "STONE_GATE_V5_CHIMNEY_SMOKE_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" }
	}
    })

    StoneGateV5:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_HOUSING_SMOKE",
	IsPlaying = true,
	IsEmitting = true
    })

    StoneGateV5:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
    })

